aboutsummaryrefslogtreecommitdiffstats
path: root/embed
diff options
context:
space:
mode:
Diffstat (limited to 'embed')
-rw-r--r--embed/mozilla/GtkNSSDialogs.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/embed/mozilla/GtkNSSDialogs.cpp b/embed/mozilla/GtkNSSDialogs.cpp
index 835b79df2..9a0afd234 100644
--- a/embed/mozilla/GtkNSSDialogs.cpp
+++ b/embed/mozilla/GtkNSSDialogs.cpp
@@ -1100,10 +1100,11 @@ fill_cert_chain_tree (GtkTreeView *treeview, nsIArray *certChain)
}
gtk_tree_view_expand_all (GTK_TREE_VIEW (treeview));
/* And select the last entry */
GtkTreeSelection *select = gtk_tree_view_get_selection (treeview);
GtkTreePath *path = gtk_tree_model_get_path (model, &parent);
gtk_tree_selection_select_path (select, path);
+ gtk_tree_view_scroll_to_cell (treeview, path, NULL, TRUE, 0.5, 0.0);
gtk_tree_path_free (path);
return TRUE;
@@ -1100,10 +1100,11 @@ fill_cert_chain_tree (GtkTreeView *treeview, nsIArray *certChain)
}
gtk_tree_view_expand_all (GTK_TREE_VIEW (treeview));
- /* And select the last entry */
+ /* And select the last entry, and scroll the view so it's visible */
GtkTreeSelection *select = gtk_tree_view_get_selection (treeview);
GtkTreePath *path = gtk_tree_model_get_path (model, &parent);